@@ -45,7 +45,8 @@ def get(dataset, **kwargs):
     :param str sort_order: options are asc, desc. Default: `asc`
     :param str returns: specify what format you wish your dataset returned as,
         either `numpy` for a numpy ndarray or `pandas`. Default: `pandas`
-    :param str text: specify whether to print output text to stdout, pass 'no' to supress output.
+    :param bool verbose: specify whether to print output text to stdout, default is False.
+    :param str text: Deprecated. Use `verbose` instead.
     :returns: :class:`pandas.DataFrame` or :class:`numpy.ndarray`
 
     Note that Pandas expects timeseries data to be sorted ascending for most
@@ -56,8 +57,15 @@ def get(dataset, **kwargs):
 
     """
     kwargs.setdefault('sort_order', 'asc')
-    text = kwargs.get('text','yes')
-    auth_token = _getauthtoken(kwargs.pop('authtoken', ''),text)
+    verbose = kwargs.get('verbose', False)
+    if 'text' in kwargs:
+        print('Deprecated: "text" is deprecated and will be removed in next release, use "verbose" instead.')
+        if isinstance(kwargs['text'], (strings, str)):
+            if kwargs['text'].lower() in ['yes', 'y', 't', 'true', 'on']:
+                verbose = True
+        else:
+            verbose = bool(kwargs['text'])
+    auth_token = _getauthtoken(kwargs.pop('authtoken', ''), verbose)
     trim_start = _parse_dates(kwargs.pop('trim_start', None))
     trim_end = _parse_dates(kwargs.pop('trim_end', None))
     returns = kwargs.get('returns', 'pandas')
@@ -84,7 +92,7 @@ def get(dataset, **kwargs):
     #If wrong format
     else:
         error = "Your dataset must either be specified as a string (containing a Quandl code) or an array (of Quandl codes) for multisets"
-        raise Exception(error)
+        raise WrongFormat(error)
         
     #Append all parameters to API call
     url = _append_query_fields(url,
@@ -92,71 +100,40 @@ def get(dataset, **kwargs):
                                trim_start=trim_start,
                                trim_end=trim_end,
                                **kwargs)
-    
-    #Determine format data is retrieved in
-    if returns == 'numpy':
-        try:
-            u = urlopen(url)
-            try:
-                array = genfromtxt(u, names=True, delimiter=',', dtype=None)
-            except ValueError as e:
-                error = "Currently we only support multisets with up to 100 columns. Please contact connect@quandl.com if this is a problem."
-                raise Exception(error)
+    if returns == 'url':
+        return url      # for test purpose
+    try:
+        urldata = _download(url)
+        if urldata.columns.size > 100:
+            error = "Currently we only support multisets with up to 100 columns. Please contact connect@quandl.com if this is a problem."
+            raise MultisetLimit(error)
+        else:
+            if verbose and verbose != 'no':
+                print("Returning Dataframe for ", dataset)
 
-            return array
-        #Errors
-        except IOError as e:
+    #Error catching
+    except HTTPError as e:
+        #API limit reached
+        if str(e) == 'HTTP Error 403: Forbidden':
+            error = 'API daily call limit exceeded. Contact us at connect@quandl.com if you want an increased daily limit'
+            raise CallLimitExceeded(error)
+
+        #Dataset not found
+        elif str(e) == 'HTTP Error 404: Not Found':
+            error = "Dataset not found. Check Quandl code: {} for errors".format(dataset)
+            raise DatasetNotFound(error)
+
+        #Catch all
+        else:
             print("url:", url)
-            raise Exception("Parsing Error! {}".format(e))
-        except HTTPError as e:
-            #API limit reached
-            if str(e) == 'HTTP Error 403: Forbidden':
-                error = 'API daily call limit exceeded. Contact us at connect@quandl.com if you want an increased daily limit'
-                raise Exception(error)
-                
-            #Dataset not found    
-            elif str(e) == 'HTTP Error 404: Not Found':
-                error = "Dataset not found. Check Quandl code: {} for errors".format(dataset)
-                raise Exception(error)
-            #Catch all
-            else:    
-                print("url:", url)
-                error = "Error Downloading! {}".format(e)
-                raise Exception(error)
-    else: # assume pandas is requested
-        try:
-            urldata = _download(url)
+            error = "Error Downloading! {}".format(e)
+            raise ErrorDownloading(error)
 
-            if urldata.columns.size > 100:
-                error = "Currently we only support multisets with up to 100 columns. Please contact connect@quandl.com if this is a problem."
-                raise Exception(error)
-            else:
-                if text == "no":
-                    pass
-                else:
-                    print("Returning Dataframe for ", dataset)
-                return urldata
-        
-        
-        #Error catching
-        except HTTPError as e:
-            #API limit reached 
-            if str(e) == 'HTTP Error 403: Forbidden':
-                error = 'API daily call limit exceeded. Contact us at connect@quandl.com if you want an increased daily limit'
-                raise Exception(error)
-                
-            #Dataset not found    
-            elif str(e) == 'HTTP Error 404: Not Found':
-                error = "Dataset not found. Check Quandl code: {} for errors".format(dataset)
-                raise Exception(error)
-                
-            #Catch all 
-            else:    
-                print("url:", url)
-                error = "Error Downloading! {}".format(e)
-                raise Exception(error)
+    if returns == 'numpy':
+        return urldata.to_records()
+    return urldata
 
-def push(data, code, name, authtoken='', desc='', override=False,text='yes'):
+def push(data, code, name, authtoken='', desc='', override=False, verbose=False, text=None):
     ''' Upload a pandas Dataframe to Quandl and returns link to the dataset.
 
     :param data: (required), pandas ts or numpy array
@@ -166,16 +143,20 @@ def push(data, code, name, authtoken='', desc='', override=False,text='yes'):
     :param str authtoken: (required), to upload data
     :param str desc: (optional), Description of dataset
     :param bool overide: (optional), whether to overide dataset of same code
-    :param str text: specify whether to print output text to stdout, pass 'no' to supress output.
-    
+    :param bool verbose: specify whether to print output text to stdout, default is False.
+    :param str text: Deprecated. Use `verbose` instead.
+
     :returns: :str: link to uploaded dataset'''
 
     override = str(override).lower()
-    token = _getauthtoken(authtoken,text)
+    if text is not None:
+        print('Deprecated: "text" is deprecated and will be removed in next release, use "verbose" instead.')
+        verbose = text
+    token = _getauthtoken(authtoken, verbose)
     if token == '':
         error = ("You need an API token to upload your data to Quandl, "
                  "please see www.quandl.com/API for more information.")
-        raise Exception(error)
+        raise MissingToken(error)
 
     #test that code is acceptable format
     _pushcodetest(code)
@@ -202,7 +183,7 @@ def push(data, code, name, authtoken='', desc='', override=False,text='yes'):
             except ValueError:
                 error = ("Please check your indices, one of them is "
                          "not a recognizable date")
-                raise Exception(error)
+                raise DateNotRecognized(error)
         for n in i:
             if isinstance(n, (float, int)):
                 datestr += ',' + str(n)
@@ -229,7 +210,7 @@ def push(data, code, name, authtoken='', desc='', override=False,text='yes'):
     return rtn
 
 
-def search(query, source = None, page= 1 , authtoken = None, prints = True):
+def search(query, source=None, page=1, authtoken=None, verbose=True, prints=None):
     """Return array of dictionaries of search results.
 
     :param str query: (required), query to search with
@@ -239,8 +220,11 @@ def search(query, source = None, page= 1 , authtoken = None, prints = True):
     :returns: :array: search results
 
     """
-    
-    token = _getauthtoken(authtoken,prints)
+
+    if prints is not None:
+        print('Deprecated: "prints" is depreciated and will be removed in next release, use "verbose" instead.')
+        verbose = prints
+    token = _getauthtoken(authtoken, verbose)
     search_url = 'http://www.quandl.com/api/v1/datasets.json?request_source=python&request_version=2&query='
     #parse query for proper API submission
     parsedquery = re.sub(" ", "+", query)
@@ -269,7 +253,7 @@ def search(query, source = None, page= 1 , authtoken = None, prints = True):
         temp_dict['freq'] = datasets[i]['frequency']
         temp_dict['colname'] = datasets[i]['column_names']
         datalist.append(temp_dict)
-        if prints and i < 4:
+        if verbose and i < 4:
             print('{0:20}       :        {1:50}'.format('Name',temp_dict['name']))
             print('{0:20}       :        {1:50}'.format('Quandl Code',temp_dict['code']))
             print('{0:20}       :        {1:50}'.format('Description',temp_dict['desc']))
@@ -313,7 +297,7 @@ def _pushcodetest(code):
     if regex.search(code):
         error = ("Your Quandl Code for uploaded data must consist of only "
                  "capital letters, underscores and numbers.")
-        raise Exception(error)
+        raise CodeFormatError(error)
     return code
 
 def _getauthtoken(token,text):
@@ -341,7 +325,7 @@ def _getauthtoken(token,text):
                 print("See www.quandl.com/api for more information.")
     elif savedtoken and not token:
         token = savedtoken
-        if text == "no":
+        if text == "no" or text == False:
              pass
         else:
             print("Using cached token {} for authentication.".format(token))
@@ -353,3 +337,50 @@ def _append_query_fields(url, **kwargs):
     field_values = ['{0}={1}'.format(key, val)
                     for key, val in kwargs.items() if val]
     return url + 'request_source=python&request_version=2&' +'&'.join(field_values)
+
+# Setup custom Exceptions
+
+
+class WrongFormat(Exception):
+    """Exception for dataset formatting errors"""
+    pass
+
+
+class MultisetLimit(Exception):
+    """Exception for calls exceeding the multiset limit"""
+    pass
+
+
+class ParsingError(Exception):
+    """Exception for I/O parsing errors"""
+    pass
+
+
+class CallLimitExceeded(Exception):
+    """Exception for daily call limit being exceeded"""
+    pass
+
+
+class DatasetNotFound(Exception):
+    """Exception for the dataset not being found"""
+    pass
+
+
+class ErrorDownloading(Exception):
+    """Catch all exception for download errors"""
+    pass
+
+
+class MissingToken(Exception):
+    """Exception when API token needed but missing"""
+    pass
+
+
+class DateNotRecognized(Exception):
+    """Exception when a date is not recognized as such"""
+    pass
+
+
+class CodeFormatError(Exception):
+    """Exception when a Quandl code is not formatted properly"""
+    pass
